/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.basher;

import java.util.Date;

/**
 * @author Johan Lindquist
 * @version 1.0
 */
public class Average
{
    private long _minTime;
    private long _maxTime;
    private long _totalTime;
    private long _totalEntries;
    private long _timeElapsed;
    private Date _timeStamp;

    public Average(final long minTime, final long maxTime, final long totalTime, final long timeElapsed, final long totalEntries)
    {
        _minTime = minTime;
        _maxTime = maxTime;
        _totalTime = totalTime;
        _totalEntries = totalEntries;
        _timeElapsed = timeElapsed;
        _timeStamp = new Date();
    }

    public long getTimeElapsed()
    {
        return _timeElapsed;
    }

    public long getAverage()
    {
        if (_totalEntries == 0)
        {
            return 0;
        }
        return _totalTime / _totalEntries;
    }

    public long getMinTime()
    {
        return _minTime;
    }

    public long getMaxTime()
    {
        return _maxTime;
    }

    public long getTotalTime()
    {
        return _totalTime;
    }

    public long getTotalEntries()
    {
        return _totalEntries;
    }

    public Date getTimeStamp()
    {
        return new Date(_timeStamp.getTime());
    }

    public float getTPS()
    {
        final float seconds = (_timeElapsed / 1000);
        if (seconds ==0)
        {
            return 0f;
        }
        return _totalEntries / seconds;
    }

    public String toString()
    {
        return "elapsed time: " + _timeElapsed +" min time: " + (_minTime==Long.MAX_VALUE? "N/A":""+_minTime) + " max time: " + _maxTime +" total time: " + _totalTime + " calls: " + _totalEntries + " average time: " + getAverage() + " tps: " + getTPS();
    }
}
