/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.basher.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import net.sourceforge.basher.Average;
import net.sourceforge.basher.Collector;
import net.sourceforge.basher.Task;
import net.sourceforge.basher.internal.TimeSource;
import org.apache.commons.logging.Log;

/**
 * @author Johan Lindquist
 * @version 1.0
 */
public abstract class AbstractCollector implements Collector
{
    protected long _successes;
    protected long _failures;
    protected long _notRun;

    protected long _min = 0;
    protected long _max;
    protected long _total;
    protected long _timeElapsed = System.currentTimeMillis();

    private List _averages = new ArrayList();
    protected Log _logger;
    private boolean _collecting;
    protected TimeSource _timeSource;

    public void startCollecting()
    {
        _collecting = true;
    }

    public void stopCollecting()
    {
        _collecting = false;
    }

    public void success(Task task, final long elapsedTime)
    {
        _successes++;
        updateStats(elapsedTime);
    }

    public void notRun(Task task, final long elapsedTime)
    {
        _notRun++;
        // We omit stats for not run tasks
    }

    public void fail(Task task, final long elapsedTime, Throwable throwable)
    {
        _failures++;
        updateStats(elapsedTime);
    }

    private void updateStats(final long elapsedTime)
    {
        _total += elapsedTime;
        if (elapsedTime < _min)
        {
            _min = elapsedTime;
        }
        if (elapsedTime > _max)
        {
            _max = elapsedTime;
        }
    }

    public long getFailures()
    {
        return _failures;
    }

    public long getSuccesses()
    {
        return _successes;
    }

    public long getNotRun()
    {
        return _notRun;
    }

    public long getTotal()
    {
        return _failures + _successes;
    }

    public List getAverages()
    {
        return Collections.unmodifiableList(_averages);
    }

    public Average markAverage()
    {
        final Average average = new Average(_min, _max, _total, (System.currentTimeMillis() - _timeElapsed), _successes + _failures);
        if (isCollecting())
        {
            _averages.add(average);
        }
        _min = Long.MAX_VALUE;
        _max = 0;
        _total = 0;
        _successes = 0;
        _failures = 0;
        _notRun = 0;
        _timeElapsed = System.currentTimeMillis();

        return average;
    }

    public void setTimeSource(final TimeSource timeSource)
    {
        _timeSource = timeSource;
    }

    public void setLog(final Log logger)
    {
        _logger = logger;
    }

    public boolean isCollecting()
    {
        return _collecting;
    }
}
