/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.basher.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

import net.sourceforge.basher.Task;
import net.sourceforge.basher.TaskManager;
import net.sourceforge.basher.internal.Randomizer;
import org.apache.commons.logging.Log;

/**
 * @author Johan Lindquist
 * @version 1.0
 */
public class TaskManagerImpl implements TaskManager
{
    private List _taskInfos;
    private List _tasks;
    private Randomizer _randomizer;
    private List _removedTasks;
    private Log _logger;

    public void setLog(final Log logger)
    {
        _logger = logger;
    }

    public void setRandomizer(final Randomizer randomizer)
    {
        _randomizer = randomizer;
    }

    public synchronized  void addTask(final Task task)
    {
        checkInitialized();
        if (task == null)
        {
            throw new NullPointerException("task");
        }
        // Move the task from removed to active
        if (_removedTasks.contains(task))
        {
            _removedTasks.remove(task);
        }
        _tasks.add(task);
        _logger.info("Task '" + task.getName() + "' added");
    }

    public Task getNextRandomTask()
    {
        checkInitialized();
        if (_tasks.size() == 0)
        {
            _logger.warn("No active tasks available");
            return null;
        }
        final int nextRandom = _randomizer.getRandomInt(_tasks.size());
        return (Task) _tasks.get(nextRandom);
    }

    public List getTasks()
    {
        checkInitialized();
        return Collections.unmodifiableList(_tasks);
    }

    public Task getTaskByName(String name)
    {
        checkInitialized();
        for (Iterator iterator = _tasks.iterator(); iterator.hasNext();)
        {
            Task task = (Task) iterator.next();
            if (task.getName().equals(name))
            {
                return task;
            }
        }
        for (Iterator iterator = _removedTasks.iterator(); iterator.hasNext();)
        {
            Task task = (Task) iterator.next();
            if (task.getName().equals(name))
            {
                return task;
            }
        }
        return null;
    }

    public void removeTask(Task task)
    {
        checkInitialized();
        if (_tasks.contains(task))
        {
            _logger.info("Removing task '" + task.getName() + "' from active list");
            _tasks.remove(task);
            _removedTasks.add(task);
        }
        else
        {
            _logger.warn("Task '" + task.getName() + "' not in active list, can not remove");
        }
    }

    public List getRemovedTasks()
    {
        checkInitialized();
        return Collections.unmodifiableList(_removedTasks);
    }

    private void checkInitialized()
    {
        if (_tasks == null)
        {
            throw new IllegalStateException("not initialized");
        }
    }

    public int getNumberOfRemovedTasks()
    {
        checkInitialized();
        return _removedTasks.size();
    }

    public int getNumberOfTasks()
    {
        checkInitialized();
        return _tasks.size();
    }

    public void setTaskInfos(final List taskInfos)
    {
        if (taskInfos == null)
        {
            throw new NullPointerException("taskInfos");
        }
        _taskInfos = taskInfos;
    }

    public void initializeService()
    {
        if (_randomizer == null)
        {
            throw new IllegalStateException("no randomizer");
        }

        if (_logger == null)
        {
            throw new IllegalStateException("no log");
        }

        _removedTasks = new ArrayList();
        _tasks = new ArrayList();

        if (_taskInfos != null)
        {

            if (_taskInfos.size() == 0)
            {
                _logger.warn("No TaskInfo instances supplied");
                return;
            }

            for (Iterator iterator = _taskInfos.iterator(); iterator.hasNext();)
            {
                final TaskInfo taskInfo = (TaskInfo) iterator.next();
                final Task task = taskInfo.getTask();
                // Pull in the possible followers ...
                if (taskInfo.getFollowers() != null && taskInfo.getFollowers().size() > 0)
                {
                    task.setFollowers(taskInfo.getFollowers());
                }
                else
                {
                    task.setFollowers(Collections.EMPTY_LIST);
                }
                _tasks.add(task);
                _logger.debug("Task '" + task.getName() + "' added - " + task.getFollowers().size() +" follower(s)");
            }
            _logger.info("'" + _tasks.size() + "' task(s) added");
        }
        else
        {
            _logger.warn("No TaskInfo instances supplied");
        }
    }


}
