/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.basher.internal.impl;

import net.sourceforge.basher.TaskManager;
import net.sourceforge.basher.internal.Randomizer;
import net.sourceforge.basher.internal.TaskInvoker;
import net.sourceforge.basher.internal.TaskRunner;
import net.sourceforge.basher.internal.TaskRunnerFactory;
import org.apache.commons.logging.Log;

/**
 * @author Johan Lindquist
 * @version 1.0
 */
public class TaskRunnerFactoryImpl implements TaskRunnerFactory
{
    private int _count;

    private int _maxDelay = 40;
    private int _minTime = 10;

    private TaskManager _taskManager;
    private TaskInvoker _taskInvoker;
    private Randomizer _randomizer;

    private Log _logger;


    public void setMaxDelay(final int maxDelay)
    {
        _maxDelay = maxDelay;
    }

    public void setMinTime(final int minTime)
    {
        _minTime = minTime;
    }

    public void setTaskManager(final TaskManager taskManager)
    {
        _taskManager = taskManager;
    }

    public void setRandomizer(final Randomizer randomizer)
    {
        _randomizer = randomizer;
    }

    public void setTaskInvoker(final TaskInvoker taskInvoker)
    {
        _taskInvoker = taskInvoker;
    }

    public void setLog(final Log logger)
    {
        _logger = logger;
    }

    public TaskRunner createTaskRunner()
    {
        _logger.info("Creating Task Runner");
        final String name = "TaskRunnerImpl-" + _count;
        _count++;
        TaskRunnerImpl taskRunner = new TaskRunnerImpl(name);
        taskRunner.setLog(_logger);
        taskRunner.setMaxDelay(_maxDelay);
        taskRunner.setMinTime(_minTime);
        taskRunner.setRandomizer(_randomizer);
        taskRunner.setTaskInvoker(_taskInvoker);
        taskRunner.setTaskManager(_taskManager);
        _logger.info("Task Runner Created");
        return taskRunner;
    }
}
