/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.basher.internal.impl;

import net.sourceforge.basher.Basher;
import net.sourceforge.basher.Task;
import net.sourceforge.basher.TaskManager;
import net.sourceforge.basher.internal.Randomizer;
import net.sourceforge.basher.internal.TaskInvoker;
import net.sourceforge.basher.internal.TaskRunner;
import org.apache.commons.logging.Log;

/**
 * @author Johan Lindquist
 * @version 1.0
 */
public class TaskRunnerImpl implements TaskRunner
{
    private Randomizer _randomizer;
    private TaskManager _taskManager;
    private TaskInvoker _taskInvoker;
    private Log _logger;
    private boolean keepRunning = true;
    private int _minTime;
    private int _maxDelay;
    private String _name;

    public TaskRunnerImpl(final String name)
    {
        _name = name;
    }

    public String getName()
    {
        return _name;
    }

    public void setMinTime(final int minTime)
    {
        _minTime = minTime;
    }

    public void setMaxDelay(final int maxDelay)
    {
        _maxDelay = maxDelay;
    }


    public void setRandomizer(final Randomizer randomizer)
    {
        _randomizer = randomizer;
    }

    public void setLog(final Log logger)
    {
        _logger = logger;
    }

    public void setTaskManager(final TaskManager taskManager)
    {
        _taskManager = taskManager;
    }

    public void setTaskInvoker(final TaskInvoker taskInvoker)
    {
        _taskInvoker = taskInvoker;
    }


    public void stopInvoking()
    {
        keepRunning = false;
    }

    /**
     *
     */
    public void run()
    {
        while (keepRunning)
        {
            try
            {
                final Task task = _taskManager.getNextRandomTask();

                if (task != null)
                {
                    _taskInvoker.invokeTask(task);
                }
                // Simple check to ensure we dont overdo things ...
                if (keepRunning)
                {
                    Basher.fireCleanUpThread();
                    Thread.sleep(getRandomSleepTime());
                }
            }
            catch (Exception e)
            {
                _logger.error(e.getMessage(), e);
            }
        }
    }

    private long getRandomSleepTime()
    {
        // Should create (_minTime < sleepTime < (_minTime + _maxDelay))
        return _minTime + _randomizer.getRandomInt(_maxDelay);
    }


}
