/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.basher.internal.impl;

import net.sourceforge.basher.Task;
import net.sourceforge.basher.internal.TimedTaskRunner;
import net.sourceforge.basher.internal.TimedTaskRunnerFactory;
import org.apache.commons.logging.Log;

/**
 * @author Johan Lindquist
 * @version 1.0
 */
public class TimedTaskRunnerFactoryImpl implements TimedTaskRunnerFactory
{
    private int _count = 0;
    private Log _logger;

    public void setLog(final Log logger)
    {
        _logger = logger;
    }

    public TimedTaskRunner createTimedTaskRunner(long interval, Task task)
    {
        _logger.info("Creating Timed Task Runner for task '" + task.getName() +"' running at interval of '" +interval +"' seconds");
        final String name = "TimedTaskRunnerImpl-" + _count;
        TimedTaskRunnerImpl timedTaskRunner = new TimedTaskRunnerImpl(name);
        timedTaskRunner.setInterval(interval);
        timedTaskRunner.setLog(_logger);
        timedTaskRunner.setTask(task);
        _logger.info("Timed Task Runner created for task '" + task.getName() + "'");
        return timedTaskRunner;
    }
}
