/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.basher.internal.impl;

import net.sourceforge.basher.Task;
import net.sourceforge.basher.internal.TimedTaskRunner;
import org.apache.commons.logging.Log;

/**
 * @author Johan Lindquist
 * @version 1.0
 */
public class TimedTaskRunnerImpl implements TimedTaskRunner
{

    private long _interval;
    private Task _task;
    private boolean _keepRunning = true;
    private Log _logger;
    private String _name;

    public void setInterval(final long interval)
    {
        _interval = interval;
    }

    public void setTask(final Task task)
    {
        _task = task;
    }

    public void setLog(final Log logger)
    {
        _logger = logger;
    }

    public TimedTaskRunnerImpl(String name)
    {
        _name = name;
    }

    public String getName()
    {
        return _name;
    }

    public void stopInvoking()
    {
        _keepRunning = false;
    }

    public void run()
    {
        try
        {
            while (_keepRunning)
            {
                try
                {
                    _task.doIt();
                }
                catch (Throwable e)
                {
                    // Ignore this ...
                    _logger.error(e.getMessage(), e);
                }
                Thread.sleep(_interval * 1000);
            }
        }
        catch (Throwable throwable)
        {
            _logger.error(throwable.getMessage(), throwable);
        }
    }
}
