/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.basher.internal.tasks;

import java.util.Date;

import net.sourceforge.basher.Collector;
import net.sourceforge.basher.Scheduler;
import net.sourceforge.basher.TaskManager;
import net.sourceforge.basher.internal.TimeSource;
import net.sourceforge.basher.tasks.AbstractTask;

/**
 * @author Johan Lindquist
 * @version 1.0
 */
public class MonitorTask extends AbstractTask
{
    private Scheduler _scheduler;
    private Collector _collector;
    private TaskManager _taskManager;
    private TimeSource _timeSource;

    public void setTimeSource(final TimeSource timeSource)
    {
        _timeSource = timeSource;
    }

    public void setScheduler(final Scheduler scheduler)
    {
        _scheduler = scheduler;
    }

    public void setCollector(final Collector collector)
    {
        _collector = collector;
    }

    public void setTaskManager(final TaskManager taskManager)
    {
        _taskManager = taskManager;
    }

    public void doTask() throws Throwable
    {
        try
        {
            _log.info("[" + new Date((long)_timeSource.getCurrentTime()) + "] : Number of threads currently running: " + _scheduler.getNumberOfActiveThreads() + " (executing " + _taskManager.getNumberOfTasks() + " task(s))");
            final long total = _collector.getTotal();
            if (total != 0)
            {
                final long failures = _collector.getFailures();
                final long successes = _collector.getSuccesses();
                _log.info("(not run: " + _collector.getNotRun() + " executed: " + total + " successes: " + successes + " failures: " + failures + " success rate: " + (((total - failures) / total) * 100 + "% delta: " + total + ")"));
            }
            _collector.markAverage();
        }
        catch (Throwable e)
        {
            _log.error(e.getMessage(), e);
        }
    }

}
